@@ -26,21 +26,19 @@ import gi
 gi.require_version('Gtk', '3.0')
 gi.require_version('Vte', '2.91')  # vte-0.38
 from gi.repository import Gdk
+from gi.repository import Gio
 from gi.repository import Gtk
 from gi.repository import Pango
 from gi.repository import Vte
+from guake.utils import RectCalculator
 
 from guake.common import pixmapfile
 from locale import gettext as _
 
-GCONF_MONOSPACE_FONT_PATH = '/desktop/gnome/interface/monospace_font_name'
-DCONF_MONOSPACE_FONT_PATH = 'org.gnome.desktop.interface'
-DCONF_MONOSPACE_FONT_KEY = 'monospace-font-name'
-
 log = logging.getLogger(__name__)
 
 
-class GSettingHandler(object):
+class GSettingHandler():
 
     """Handles gconf changes, if any gconf variable is changed, a
     different method is called to handle this change.
@@ -54,7 +52,7 @@ class GSettingHandler(object):
         self.settings = guake_inst.settings
         settings = self.settings
 
-        # Notification is not required for mouse_display/display_n because
+        # Notification is not required for mouse_display/display-n because
         # set_final_window_rect polls gconf and is called whenever Guake is
         # shown or resized
 
@@ -81,6 +79,7 @@ class GSettingHandler(object):
         settings.styleFont.onChangedValue('style', self.fstyle_changed)
         settings.styleFont.onChangedValue('palette', self.fpalette_changed)
         settings.styleFont.onChangedValue('allow-bold', self.allow_bold_toggled)
+        settings.styleFont.onChangedValue('bold-is-bright', self.bold_is_bright_toggled)
         settings.styleBackground.onChangedValue('transparency', self.bgtransparency_changed)
 
         settings.general.onChangedValue('compat-backspace', self.backspace_changed)
@@ -118,15 +117,15 @@ class GSettingHandler(object):
         called and will show/hide the tabbar.
         """
         if settings.get_boolean(key):
-            self.guake.toolbar.show()
+            self.guake.notebook.set_property("show-tabs", True)
         else:
-            self.guake.toolbar.hide()
+            self.guake.notebook.set_property("show-tabs", False)
 
     def alignment_changed(self, settings, key, user_data):
         """If the gconf var window_halignment be changed, this method will
         be called and will call the move function in guake.
         """
-        self.guake.set_final_window_rect()
+        RectCalculator.set_final_window_rect(self.settings, self.guake.window)
         self.guake.set_tab_position()
         self.guake.force_move_if_shown()
 
@@ -135,7 +134,7 @@ class GSettingHandler(object):
         this method will be called and will call the resize function
         in guake.
         """
-        self.guake.set_final_window_rect()
+        RectCalculator.set_final_window_rect(self.settings, self.guake.window)
 
     def cursor_blink_mode_changed(self, settings, key, user_data):
         """Called when cursor blink mode settings has been changed
@@ -206,27 +205,18 @@ class GSettingHandler(object):
         default or to the chosen font in style/font/style in all
         terminals open.
         """
-        # TODO PORT
         font_name = None
         if settings.get_boolean(key):
-            # cannot directly use the Gio API since it requires to rework completely
-            # the library inclusion, remove dependencies on gobject and so on.
-            # Instead, issuing a direct command line request
-            c = ['gsettings', 'get', DCONF_MONOSPACE_FONT_PATH, DCONF_MONOSPACE_FONT_KEY]
-            proc = subprocess.Popen(c, stdout=subprocess.PIPE)
-            font_name = proc.stdout.readline().decode().replace("'", "")
-            if font_name is None:
-                # Back to gconf
-                font_name = settings.get_string(GCONF_MONOSPACE_FONT_PATH)
-            proc.kill()
+            gio_settings = Gio.Settings('org.gnome.desktop.interface')
+            font_name = gio_settings.get_string('monospace-font-name')
         else:
             font_name = self.settings.styleFont.get_string('style')
-
         if not font_name:
-            log.error("Error: unable to find font name !!!")
+            log.error("Error: unable to find font name (%s)", font_name)
             return
         font = Pango.FontDescription(font_name)
         if not font:
+            log.error("Error: unable to load font (%s)", font_name)
             return
         for i in self.guake.notebook.iter_terminals():
             i.set_font(font)
@@ -239,6 +229,13 @@ class GSettingHandler(object):
         for term in self.guake.notebook.iter_terminals():
             term.set_allow_bold(settings.get_boolean(key))
 
+    def bold_is_bright_toggled(self, settings, key, user_data):
+        """If the dconf var bold_is_bright is changed, this method will be called
+        and will change the VTE terminal to toggle auto-brightened bold text.
+        """
+        for term in self.guake.notebook.iter_terminals():
+            term.set_bold_is_bright(settings.get_boolean(key))
+
     def palette_font_and_background_color_toggled(self, settings, key, user_data):
         """If the gconf var use_palette_font_and_background_color be changed, this method
         will be called and will change the font color and the background color to the color
@@ -316,5 +313,5 @@ class GSettingHandler(object):
         be called and will update tab names.
         """
         abbreviate_tab_names = settings.get_boolean('abbreviate-tab-names')
-        self.guake.abbreviate = abbreviate_tab_names and self.guake.is_tabs_scrollbar_visible()
+        self.guake.abbreviate = abbreviate_tab_names
         self.guake.recompute_tabs_titles()
